@@ -22,7 +22,6 @@ Ext.define('MP.upload.StatusBar', {
     },
 
     initComponent : function() {
-
         Ext.apply(this, {
             items : [
                 {
@@ -42,12 +41,17 @@ Ext.define('MP.upload.StatusBar', {
 
     setSelectionMessage : function(fileCount, byteCount) {
         this.setText(Ext.String.format(
-            ngettext('Selected {0} file, {1}', 'Selected {0} files, {1}', fileCount),
+            // TRANSLATORS: {0} is the number of files, {1} the total size
+            ngettext('Selected {0} file, {1}',
+                     'Selected {0} files, {1}',
+                     fileCount),
             fileCount, Ext.util.Format.fileSize(byteCount)));
     },
 
     setUploadMessage : function(progressPercent, uploadedFiles, totalFiles) {
         this.setText(Ext.String.format(
+            // TRANSLATORS: {0} is the completion percentage, {1} the number of
+            // uploaded files, {2} the total number of files
             ngettext('Upload progress {0}% ({1} of {2} file)',
                      'Upload progress {0}% ({1} of {2} files)',
                      totalFiles),
